#[repr(u8)]pub enum Dma0en {
DISABLED = 0,
TRIGGERD_ON_HOST_READ = 1,
TRIGGERS_ON_HOST_WRITE = 2,
_RESERVED_3 = 3,
}Variants
DISABLED = 0
Disabled. The DMA channel is not used.
TRIGGERD_ON_HOST_READ = 1
Triggers on Host Read empty (whether endpoint and a byte or mailbox and many bytes). Allows reload of memory.
TRIGGERS_ON_HOST_WRITE = 2
Triggers on Host Write complete/ready (whether endpoint and a byte, or mailbox and many bytes).
_RESERVED_3 = 3
Implementations