#[repr(u8)]pub enum P1cfgErrorign {
ERRORIGIN0 = 0,
ERRORIGIN1 = 1,
}Variants
ERRORIGIN0 = 0
The host receives an error when trying to perform a read or write that is blocked by PnCFG[DIRECTION].
ERRORIGIN1 = 1
Ignored silently. Reads return FFh for each byte if ignored (host property). In either case, PnSTAT[INTERR] bit becomes 1, causing an interrupt if masked for it.
Implementations
Sourceimpl P1cfgErrorign
impl P1cfgErrorign