#[repr(u8)]pub enum P2irulestatFlashCompletionType {
MIDDLE = 0,
FIRST = 1,
LAST = 2,
ONLY = 3,
}Variants
MIDDLE = 0
Indicates the middle completion of a split completion sequence
FIRST = 1
Indicates the first completion of a split completion sequence
LAST = 2
Indicates the last completion of a split completion sequence
ONLY = 3
Indicates the only completion for a split transaction.
Implementations